==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/offerta.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_errata != "SI") {




$trovato = "NO";
$offribile = "SI";
$soldi_spesi = 0;
$num_calciatori_posseduti = 0;
echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td><font size=-1>Costo</font></td>
<td><font size=-1>Proprietario</font></td>
<td>__Tempo_rimasto__</td></tr>";

$calciatori = @file("dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
} # fine if ($proprietario == $nome_utente)

if ($num_calciatore == $numero) {
$trovato = "SI";
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$proprietario_vero = $proprietario;
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$tempo_restante = "COMPRATO";
$offribile = "NO";
} # fine if ($sec_restanti < 0)
else { 
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";
$vecchio_proprietario = $dati_calciatore[6];
$vecchio_costo = $dati_calciatore[7];
$nuovo_costo = $dati_calciatore[8];
} # fine else if ($sec_restanti < 0)
if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2>(venduto da $vecchio_proprietario)</font>"; }
else { $proprietario_mostra = $proprietario; }
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
echo"<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo_mostra</td>
<td>$proprietario_mostra</td>
<td>$tempo_restante</td></tr>";
} # fine if ($num_calciatore == $numero)
} # fine for $num1

if ($trovato != "SI") {
$calciatori = file("dati/calciatori.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = ereg_replace("
","",$numero);
if ($num_calciatore == $numero) {
$trovato = "SI";
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = ereg_replace("
","",$nome);
$nome = ereg_replace("\"","",$nome);
$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$ruolo = ereg_replace("
","",$ruolo);
if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
echo"<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>&nbsp;</td>
<td>&nbsp;</td>
<td>&nbsp;</td></tr>";
} # fine if ($num_calciatore == $numero)
} # fine for $num1
} # fine if ($trovato != "SI")

if ($trovato != "SI") {
$offribile = "NO";
echo "<tr><td colspan=\"6\">Giocatore inesistente, sei un BARO!</td></tr>";
} # fine if ($trovato != "SI")
echo "</table>";

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$surplus = @file("squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($vecchio_proprietario == $nome_utente and $vecchio_proprietario != $proprietario_vero) {
$togliere_surplus = $vecchio_costo -  $costo;
$frase_togliere = " (meno $togliere_surplus Euro ricavati dalla vendita di questo giocatore)";
} # fine if ($vecchio_proprietario == $nome_utente and ...)
if ($num_calciatori_comprabili <= 0 or $soldi_spendibili <= 0) { $offribile = "NO"; }
echo "<br>Soldi ancora da spendere: <b>$soldi_spendibili</b> Euro$frase_togliere.<br>
Numero di giocatori ancora comperabili: <b>$num_calciatori_comprabili</b>.<br>";

if ($offribile == "SI") {
echo "<br><form method=\"post\" action=\"inserisci_offerta.php\">
Fai una offerta per <b>$nome</b> di
<input type=\"text\" name=\"valore_offerta\" size=\"8\">
Euro.
<input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"invia\" value=\"Invia\">
</form>";
} # fine if ($offribile == "SI");

else { echo "<br><br>Non si possono fare offerte per questo giocatore!<br>"; }

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("dati/foot.php");
?>

==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/offerta.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {


if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

$trovato = "NO";
$offribile = "SI";
$soldi_spesi = 0;
$num_calciatori_posseduti = 0;
echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td><font size=-1>Costo</font></td>
<td><font size=-1>Proprietario</font></td>
<td>__Tempo_rimasto__</td></tr>";

$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
} # fine if ($proprietario == $nome_utente)

if ($num_calciatore == $numero) {
$trovato = "SI";
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$proprietario_vero = $proprietario;
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$tempo_restante = "COMPRATO";
$offribile = "NO";
} # fine if ($sec_restanti < 0)
else { 
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";
$vecchio_proprietario = $dati_calciatore[6];
$vecchio_costo = $dati_calciatore[7];
$nuovo_costo = $dati_calciatore[8];
} # fine else if ($sec_restanti < 0)
if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2>(venduto da $vecchio_proprietario)</font>"; }
else { $proprietario_mostra = $proprietario; }
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
echo"<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo_mostra</td>
<td>$proprietario_mostra</td>
<td>$tempo_restante</td></tr>";
} # fine if ($num_calciatore == $numero)
} # fine for $num1

if ($trovato != "SI") {
$nuova_offerta = "SI";
$calciatori = file("$percorso_cartella_dati/calciatori.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = ereg_replace("
","",$numero);
if ($num_calciatore == $numero) {
$trovato = "SI";
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = ereg_replace("
","",$nome);
$nome = ereg_replace("\"","",$nome);
$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$ruolo = ereg_replace("
","",$ruolo);
if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
echo"<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>&nbsp;</td>
<td>&nbsp;</td>
<td>&nbsp;</td></tr>";
} # fine if ($num_calciatore == $numero)
} # fine for $num1
} # fine if ($trovato != "SI")

if ($trovato != "SI") {
$offribile = "NO";
echo "<tr><td colspan=\"6\">Giocatore inesistente, sei un BARO!</td></tr>";
} # fine if ($trovato != "SI")
echo "</table>";

if ($nuova_offerta == "SI" and $stato_mercato == "S") {
$offribile = "NO";
echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
} # fine if ($nuova_offerta == "SI" and $stato_mercato == "S")

if ($stato_mercato == "C") {
$offribile = "NO";
echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
} # fine if ($stato_mercato == "C")

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($vecchio_proprietario == $nome_utente and $vecchio_proprietario != $proprietario_vero) {
$togliere_surplus = $vecchio_costo -  $costo;
$frase_togliere = " (meno $togliere_surplus Fanta-Euro ricavati dalla vendita di questo giocatore)";
} # fine if ($vecchio_proprietario == $nome_utente and ...)
if ($num_calciatori_comprabili <= 0 or $soldi_spendibili <= 0) { $offribile = "NO"; }
echo "<br>Soldi ancora da spendere: <b>$soldi_spendibili</b> Fanta-Euro$frase_togliere.<br>
Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.<br>";

if ($offribile == "SI") {
echo "<br><form method=\"post\" action=\"inserisci_offerta.php\">
Fai una offerta per <b>$nome</b> di
<input type=\"text\" name=\"valore_offerta\" size=\"8\">
Fanta-Euro.
<input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"invia\" value=\"Invia\">
</form>";
} # fine if ($offribile == "SI");

else { echo "<br><br>Non si possono fare offerte per questo giocatore!<br>"; }

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
